import { AfterContentInit, ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, SimpleChanges } from "@angular/core";
import { BehaviorSubject } from "rxjs";
import { IconThemeService } from "../../services/icon-theme.service";
import { ThemeService } from "../../services/theme.service";
import * as i0 from "@angular/core";
/**
 * This component renders icons from icon8. Please make sure that the usage does not validate our license. How-to find your next icon:
 *  - goto <a href="https://icons8.de">icons8.de</a>
 *  - search for your icon
 *  - make sure it has great theme support (at least ios and ios-filled should be available)
 *  - click on the icon and goto "embed html"
 *  - copy the name of the icon (filename without extension). Example: `<img src="https://img.icons8.com/color/48/000000/edit-property.png"/>` would be "edit-property"
 *
 * @example
 * <smallstack-icon name="edit-property">
 * <smallstack-icon name="edit-property" theme="fluent">
 * <smallstack-icon name="edit-property" theme="dotty" size="128">
 *
 * @param {string} [theme=ios] - If you want to set or a theme explicitly, you can use the `theme` input of the component. Otherwise, these will be filled by the IconThemeService: `<smallstack-icon name="edit-property" theme="dotty">`
 * @param {number} [size=48] - If you want to set a size (in px) explicitly, you can use the `size` inputs of the component. Otherwise, these will be filled by the IconThemeService: `<smallstack-icon name="edit-property" size="128">`
 */
export declare class IconComponent implements OnDestroy, OnChanges, AfterContentInit {
    private iconThemeService;
    private themeService;
    private cdr;
    private elementRef;
    protected name$: BehaviorSubject<string>;
    realSize: string;
    protected iconDiv: ElementRef;
    /**
     * icons8 theme: dotty, ios, material, color, fluent etc, see icons8.de
     */
    theme: string;
    protected showOnlineIcon: boolean;
    /**
     * If you want to set a size (in px) explicitly, you can use the `size` inputs of the component.
     * You can also use daisy sizes like "md" or "xs"
     * Otherwise, these will be filled by the IconThemeService: `<smallstack-icon name="edit-property" size="128">`
     */
    set size(size: string);
    get size(): string;
    private iconSize;
    get badgeFontSize(): number;
    get hostHeight(): number;
    get hostWidth(): number;
    /**
     * name of icon
     */
    set name(name: string);
    /**
     * use predefined alias like "project" or "company". The IconThemeService will be asked to convert aliases. If not found, the alias will be used as name
     */
    set alias(alias: string);
    /**
     * Action Icon, will be displayed at the bottom right, with 33% of the icon size.
     */
    action: string;
    /** Relative size to the big one, defaults to 0.3 */
    actionSize: number;
    /** Shall the icon spin ? */
    spinning: boolean;
    /** Shall the action item spin ? */
    actionSpinning: boolean;
    /**
     * @param [color=000000] - defaults to black (000000), can be any hex color (no alpha channel) or the string "primary" which will be the primary color of the current material theme, see IconThemeService
     */
    set color(color: string);
    get color(): string;
    private convertedColor;
    /**
     * Set the color to one from a smallstack Theme, e.g. "toolbar.colors.text"
     */
    themeColor: string;
    /**
     * If the action icon shall have another color than the icon
     */
    actionColor: string;
    /**
     * If set, a badge will be displayed at the top right
     */
    badge: number;
    get calculatedBadge(): string;
    /** set to true if the icon is most likely not available in the assets folder */
    set dynamic(dynamic: boolean);
    /** Sets the color of the badge */
    badgeColor: "primary" | "secondary" | "error" | "warning" | "success" | "info" | "accent";
    readonly iconError: EventEmitter<boolean>;
    private devicePixelRatio;
    hasError: boolean;
    private subscription;
    constructor(iconThemeService: IconThemeService, themeService: ThemeService, cdr: ChangeDetectorRef, elementRef: ElementRef);
    ngAfterContentInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    onError(event: any): void;
    private applyTheme;
    static ɵfac: i0.ɵɵFactoryDeclaration<IconComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<IconComponent, "smallstack-icon", never, { "theme": { "alias": "theme"; "required": false; }; "size": { "alias": "size"; "required": false; }; "name": { "alias": "name"; "required": false; }; "alias": { "alias": "alias"; "required": false; }; "action": { "alias": "action"; "required": false; }; "actionSize": { "alias": "actionSize"; "required": false; }; "spinning": { "alias": "spinning"; "required": false; }; "actionSpinning": { "alias": "actionSpinning"; "required": false; }; "color": { "alias": "color"; "required": false; }; "themeColor": { "alias": "themeColor"; "required": false; }; "actionColor": { "alias": "actionColor"; "required": false; }; "badge": { "alias": "badge"; "required": false; }; "dynamic": { "alias": "dynamic"; "required": false; }; "badgeColor": { "alias": "badgeColor"; "required": false; }; }, { "iconError": "iconError"; }, never, never, true, never>;
}
